@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 from __future__ import with_statement
+import os
 import re
 from helper import json, shell_exec, mkdir_p, rmdir, kill_pid
 from exception import SftpConfigException
@@ -11,7 +12,6 @@ class EnvironmentModel(object):
     """
 
     def __init__(self):
-        import os
         self.mount_path_base = '/mnt/sshfs/'
         self.config_path_base = os.path.expanduser('~/.config/sftpman/')
         self.config_path_mounts = '%smounts/' % self.config_path_base
@@ -40,6 +40,8 @@ class EnvironmentModel(object):
         return None
 
     def get_available_ids(self):
+        if not os.path.exists(self.config_path_mounts):
+            return []
         cfg_files = shell_exec('/bin/ls %s' % self.config_path_mounts).strip().split('\n')
         return [file_name[0:-3] for file_name in cfg_files if file_name.endswith('.js')]
 
@@ -68,8 +70,6 @@ class EnvironmentModel(object):
         sshfs filesystems.
         :return: two-tuple (boolean checks_pass, list failure messages)
         """
-        import os
-
         failures = []
         if not os.access(self.mount_path_base, os.W_OK):
             msg = ("Mount path `{path}` doesn't exist or is not writable"
@@ -108,12 +108,23 @@ class SystemModel(object):
 
     port = property(lambda self: self._port, _set_port)
 
+    def _set_ssh_key(self, value):
+        if value is not None:
+            value = os.path.expanduser(value)
+        self._ssh_key = value
+
+    ssh_key = property(lambda self: self._ssh_key, _set_ssh_key)
+
     def validate(self):
         def is_alphanumeric(value):
+            if value is None:
+                return False
             # Well, not really alphanumeric, but close enough to call it that
             return re.compile('^[a-zA-Z0-9\.\-]+$').match(value) is not None
 
         def is_valid_path(value):
+            if value is None:
+                return False
             return re.compile('^(/[a-zA-Z0-9\.\-]+)+/?$').match(value) is not None
 
         errors = []
@@ -124,7 +135,7 @@ class SystemModel(object):
         if not is_valid_path(self.mount_point):
             errors.append(('mount_point', 'Invalid remote mount point.'))
         if not is_valid_path(self.ssh_key):
-            errors.append(('mount_point', 'Invalid ssh key path.'))
+            errors.append(('ssh_key', 'Invalid ssh key path.'))
         if not is_alphanumeric(self.user):
             errors.append(('user', 'Usernames can only contain letters and digits.'))
         if not(self.PORT_RANGE_MIN < self.port <= self.PORT_RANGE_MAX):
@@ -155,12 +166,12 @@ class SystemModel(object):
 
     def save(self, environment):
         path = environment.get_system_config_path(self.id)
+        mkdir_p(os.path.dirname(path))
         with open(path, 'w') as f:
             f.write(self.export())
 
     def delete(self, environment):
         path = environment.get_system_config_path(self.id)
-        import os
         os.unlink(path)
 
     @staticmethod
@@ -225,7 +236,10 @@ class SystemControllerModel(object):
 
         self._mount_point_local_create()
 
-        sshfs_options = " -o %s" % " -o ".join(self.system.mount_opts)
+        if len(self.system.mount_opts) == 0:
+            sshfs_options = ""
+        else:
+            sshfs_options = " -o %s" % " -o ".join(self.system.mount_opts)
 
         cmd = ("{cmd_before_mount} &&"
                " /usr/bin/sshfs -o ssh_command='/usr/bin/ssh -p {port} -i {key}'"
